======================================
Simple Naive Bayes Classifier - Python
======================================

Naive Bayes Classifier is an algorithm to classify texts into sets that is always learning.

The most obvious practical use of it is for Email Spam/Ham Detection.

Source Code
-----------

Please go to the Github Repo `here<https://github.com/tistaharahap/python-bayes-redis>`_ for more info.